@@ -10,6 +10,8 @@ from .util import ensure_dir
 
 _UNSET = object()
 
+CONFIG_FILE_ENCODING = 'utf-8'
+
 
 def get_config_parser():
     return configparser.ConfigParser()  # keep this for backward compatibility
@@ -97,11 +99,32 @@ class CLIConfig(object):
             raise last_ex  # pylint:disable=raising-bad-type
         return fallback
 
+    def sections(self):
+        combined_sections = []
+        # Go through the config chain and combine all sections
+        for config in self._config_file_chain if self.use_local_config else self._config_file_chain[-1:]:
+            sections = config.sections()
+            for section in sections:
+                if section not in combined_sections:
+                    combined_sections.append(section)
+        return combined_sections
+
     def items(self, section):
         import re
-        pattern = self.env_var_name(section, '.+')
-        candidates = [(k.split('_')[-1], os.environ[k], k) for k in os.environ.keys() if re.match(pattern, k)]
-        result = {c[0]: c for c in candidates}
+        # Only allow valid env vars, in all caps: CLI_SECTION_TEST_OPTION, CLI_SECTION__TEST_OPTION
+        pattern = self.env_var_name(section, '([0-9A-Z_]+)')
+        env_entries = []
+        for k in os.environ:
+            # Must be a full match, otherwise CLI_SECTION_T part in CLI_MYSECTION_Test_Option will match
+            matched = re.fullmatch(pattern, k)
+            if matched:
+                # (name, value, ENV_VAR_NAME)
+                item = (matched.group(1).lower(), os.environ[k], k)
+                env_entries.append(item)
+
+        # Prepare result with env entries first
+        result = {c[0]: c for c in env_entries}
+        # Add entries from config files if they do not exist yet
         for config in self._config_file_chain if self.use_local_config else self._config_file_chain[-1:]:
             try:
                 entries = config.items(section)
@@ -169,18 +192,21 @@ class _ConfigFile(object):
         self.config_comment = config_comment
         self.config_parser = configparser.ConfigParser()
         if os.path.exists(config_path):
-            self.config_parser.read(config_path)
+            self.config_parser.read(config_path, encoding=CONFIG_FILE_ENCODING)
 
     def items(self, section):
         return self.config_parser.items(section) if self.config_parser else []
 
+    def sections(self):
+        return self.config_parser.sections() if self.config_parser else []
+
     def has_option(self, section, option):
         return self.config_parser.has_option(section, option) if self.config_parser else False
 
     def get(self, section, option):
         if self.config_parser:
             return self.config_parser.get(section, option)
-        raise configparser.NoOptionError(section, option)
+        raise configparser.NoOptionError(option, section)
 
     def getint(self, section, option):
         return int(self.get(section, option))
@@ -196,7 +222,7 @@ class _ConfigFile(object):
 
     def set(self, config):
         ensure_dir(self.config_dir)
-        with open(self.config_path, 'w') as configfile:
+        with open(self.config_path, 'w', encoding=CONFIG_FILE_ENCODING) as configfile:
             if self.config_comment:
                 configfile.write(self.config_comment + '\n')
             config.write(configfile)
@@ -234,6 +260,3 @@ class _ConfigFile(object):
             for section in self.config_parser.sections():
                 self.config_parser.remove_section(section)
             self.set(self.config_parser)
-
-    def sections(self):
-        return self.config_parser.sections()
