@@ -4,10 +4,7 @@
 # --------------------------------------------------------------------------------------------
 
 import unittest
-try:
-    import mock
-except ImportError:
-    from unittest import mock
+from unittest import mock
 
 import sys
 import argparse
@@ -64,7 +61,7 @@ class TestCommandPreview(unittest.TestCase):
         with self.assertRaises(SystemExit):
             self.cli_ctx.invoke('-h'.split())
         actual = self.io.getvalue()
-        expected = u"""
+        expected = """
 Group
     {}
 
